@@ -9,6 +9,10 @@
 GPUFUN
 void LimitRect_track_local_particle(LimitRectData el, LocalParticle* part0){
 
+    if(LocalParticle_check_track_flag(part0, XS_FLAG_IGNORE_LOCAL_APERTURE)){
+        return;
+    }
+
     double const min_x = LimitRectData_get_min_x(el);
     double const max_x = LimitRectData_get_max_x(el);
     double const min_y = LimitRectData_get_min_y(el);
