@@ -1,10 +1,16 @@
+// copyright ############################### //
+// This file is part of the Xtrack Package.  //
+// Copyright (c) CERN, 2025.                 //
+// ######################################### //
 #ifndef XTRACK_TRACK_SROTATION_H
 #define XTRACK_TRACK_SROTATION_H
 
+#include <headers/track.h>
 
-/*gpufun*/
-void SRotation_single_particle(LocalParticle* part, double sin_z, double cos_z){
 
+GPUFUN
+void SRotation_single_particle(LocalParticle* part, double sin_z, double cos_z)
+{
     double const x  = LocalParticle_get_x(part);
     double const y  = LocalParticle_get_y(part);
     double const px = LocalParticle_get_px(part);
@@ -19,7 +25,6 @@ void SRotation_single_particle(LocalParticle* part, double sin_z, double cos_z){
     LocalParticle_set_y(part, y_hat);
     LocalParticle_set_px(part, px_hat);
     LocalParticle_set_py(part, py_hat);
-
 }
 
 #endif
\ No newline at end of file
