@@ -12,5 +12,7 @@
 #define  RNG_ERR_SEEDS_NOT_SET   -20
 #define  RNG_ERR_INVALID_TRACK   -21
 #define  RNG_ERR_RUTH_NOT_SET    -22
+#define  XT_INVALID_SLICE_TRANSFORM -40
+#define  XT_INVALID_CURVED_SLICE_TRANSFORM -41
 
 #endif /* XTRACK_PARTICLE_STATES_H */
