@@ -89,6 +89,8 @@ def compute_linear_normal_form(M, symplectify=False, only_4d_block=False,
         6x6 matrix
     Rot : np.ndarray
         6x6 matrix
+    eigenvalues : np.ndarray
+        3x1 vector
     '''
 
     if only_4d_block:
@@ -114,51 +116,9 @@ def compute_linear_normal_form(M, symplectify=False, only_4d_block=False,
     if stability_tol is not None:
         _assert_matrix_stability(w0, stability_tol)
 
-    a0 = np.real(v0)
-    b0 = np.imag(v0)
 
-    index_list = [0,5,1,2,3,4] # we mix them up to check the algorithm
 
-    ##### Sort modes in pairs of conjugate modes #####
-    conj_modes = np.zeros([3,2], dtype=np.int64)
-    for j in [0,1]:
-        conj_modes[j,0] = index_list[0]
-        del index_list[0]
-
-        min_index = 0
-        min_diff = abs(np.imag(w0[conj_modes[j,0]] + w0[index_list[min_index]]))
-        for i in range(1,len(index_list)):
-            diff = abs(np.imag(w0[conj_modes[j,0]] + w0[index_list[i]]))
-            if min_diff > diff:
-                min_diff = diff
-                min_index = i
-
-        conj_modes[j,1] = index_list[min_index]
-        del index_list[min_index]
-
-    conj_modes[2,0] = index_list[0]
-    conj_modes[2,1] = index_list[1]
-
-    ##################################################
-    #### Select mode from pairs with positive (real @ S @ imag) #####
-
-    modes = np.empty(3, dtype=np.int64)
-    for ii,ind in enumerate(conj_modes):
-        if np.matmul(np.matmul(a0[:,ind[0]], S), b0[:,ind[0]]) > 0:
-            modes[ii] = ind[0]
-        else:
-            modes[ii] = ind[1]
-
-    ##################################################
-    #### Sort modes such that (1,2,3) is close to (x,y,zeta) ####
-    # Identify the longitudinal mode
-    for i in [0,1]:
-        if abs(v0[:,modes[2]])[5] < abs(v0[:,modes[i]])[5]:
-            modes[2], modes[i] = modes[i], modes[2]
-
-    # Identify the vertical mode
-    if abs(v0[:,modes[1]])[2] < abs(v0[:,modes[0]])[2]:
-        modes[0], modes[1] = modes[1], modes[0]
+    modes = sort_modes(v0, w0)
 
     ##################################################
     #### Rotate eigenvectors to the Courant-Snyder parameterization ####
@@ -180,9 +140,23 @@ def compute_linear_normal_form(M, symplectify=False, only_4d_block=False,
     b2 = v0[:,modes[1]].imag
     b3 = v0[:,modes[2]].imag
 
-    n1 = 1./np.sqrt(np.matmul(np.matmul(a1, S), b1))
-    n2 = 1./np.sqrt(np.matmul(np.matmul(a2, S), b2))
-    n3 = 1./np.sqrt(np.matmul(np.matmul(a3, S), b3))
+    n1_inv_sq = np.matmul(np.matmul(a1, S), b1)
+    n2_inv_sq = np.matmul(np.matmul(a2, S), b2)
+    n3_inv_sq = np.matmul(np.matmul(a3, S), b3)
+
+    if only_4d_block:
+        n3_inv_sq = 1.0 # Just to avoid errors
+
+    if not n1_inv_sq > 0:
+        raise ValueError('Invalid n1')
+    if not n2_inv_sq > 0:
+        raise ValueError('Invalid n2')
+    if not n3_inv_sq > 0 :
+        raise ValueError('Invalid n3')
+
+    n1 = 1./np.sqrt(n1_inv_sq)
+    n2 = 1./np.sqrt(n2_inv_sq)
+    n3 = 1./np.sqrt(n3_inv_sq)
 
     a1 *= n1
     a2 *= n2
@@ -239,3 +213,54 @@ def _assert_matrix_stability(eigenvals, tol=1e-3):
     if np.any(np.abs(eigenvals) > 1. + tol):
         raise ValueError('One-turn matrix is unstable. '
                          f'Magnitudes of eigenvalues are:\n{repr(np.abs(eigenvals))}')
+
+
+def sort_modes(v0, w0):
+
+    a0 = np.real(v0)
+    b0 = np.imag(v0)
+
+    index_list = [0,5,1,2,3,4] # we mix them up to check the algorithm
+
+    ##### Sort modes in pairs of conjugate modes #####
+    conj_modes = np.zeros([3,2], dtype=np.int64)
+    for j in [0,1]:
+        conj_modes[j,0] = index_list[0]
+        del index_list[0]
+
+        min_index = 0
+        min_diff = abs(np.imag(w0[conj_modes[j,0]] + w0[index_list[min_index]]))
+        for i in range(1,len(index_list)):
+            diff = abs(np.imag(w0[conj_modes[j,0]] + w0[index_list[i]]))
+            if min_diff > diff:
+                min_diff = diff
+                min_index = i
+
+        conj_modes[j,1] = index_list[min_index]
+        del index_list[min_index]
+
+    conj_modes[2,0] = index_list[0]
+    conj_modes[2,1] = index_list[1]
+
+    ##################################################
+    #### Select mode from pairs with positive (real @ S @ imag) #####
+
+    modes = np.empty(3, dtype=np.int64)
+    for ii,ind in enumerate(conj_modes):
+        if np.matmul(np.matmul(a0[:,ind[0]], S), b0[:,ind[0]]) > 0:
+            modes[ii] = ind[0]
+        else:
+            modes[ii] = ind[1]
+
+    ##################################################
+    #### Sort modes such that (1,2,3) is close to (x,y,zeta) ####
+    # Identify the longitudinal mode
+    for i in [0,1]:
+        if abs(v0[:,modes[2]])[5] < abs(v0[:,modes[i]])[5]:
+            modes[2], modes[i] = modes[i], modes[2]
+
+    # Identify the vertical mode
+    if abs(v0[:,modes[1]])[2] < abs(v0[:,modes[0]])[2]:
+        modes[0], modes[1] = modes[1], modes[0]
+
+    return modes
\ No newline at end of file
