@@ -326,8 +326,10 @@ class OrbitCorrectionSinglePlane:
                             element_name=self.start)
         else:
             twinit = None
+        method = '4d' if delta0 is not None else None
         tw_orbit = self.line.twiss(only_orbit=True, start=self.start, end=self.end,
-                                     init=twinit, reverse=False, delta0=delta0)
+                                   init=twinit, reverse=False, delta0=delta0,
+                                   method=method)
         return tw_orbit
 
     def _measure_position(self, tw_orbit=None):
@@ -380,32 +382,32 @@ class OrbitCorrectionSinglePlane:
                 self.line.vars[corr_knob_name] = 0
 
             if self.plane == 'x':
-                if (self.line.element_refs[nn_kick].knl[0]._expr is None or
+                if (self.line.ref.elements[nn_kick].knl[0]._expr is None or
                     (self.line.vars[corr_knob_name]
-                    not in self.line.element_refs[nn_kick].knl[0]._expr._get_dependencies())):
-                    if self.line.element_refs[nn_kick].knl[0]._expr is not None:
-                        self.line.element_refs[nn_kick].knl[0] -= ( # knl[0] is -kick
+                    not in self.line.ref.elements[nn_kick].knl[0]._expr._get_dependencies())):
+                    if self.line.ref.elements[nn_kick].knl[0]._expr is not None:
+                        self.line.ref.elements[nn_kick].knl[0] -= ( # knl[0] is -kick
                             self.line.vars[f'orbit_corr_{nn_kick}_x'])
                     else:
                         # Workarond for https://github.com/xsuite/xsuite/issues/501
-                        val = self.line.element_refs[nn_kick].knl[0]._value
+                        val = self.line.ref.elements[nn_kick].knl[0]._value
                         if hasattr(val, 'get'):
                             val = val.get()
-                        self.line.element_refs[nn_kick].knl[0] = val - (
+                        self.line.ref.elements[nn_kick].knl[0] = val - (
                             self.line.vars[f'orbit_corr_{nn_kick}_x'])
             elif self.plane == 'y':
-                if (self.line.element_refs[nn_kick].ksl[0]._expr is None or
+                if (self.line.ref.elements[nn_kick].ksl[0]._expr is None or
                     (self.line.vars[corr_knob_name]
-                    not in self.line.element_refs[nn_kick].ksl[0]._expr._get_dependencies())):
-                    if  self.line.element_refs[nn_kick].ksl[0]._expr is not None:
-                        self.line.element_refs[nn_kick].ksl[0] += ( # ksl[0] is +kick
+                    not in self.line.ref.elements[nn_kick].ksl[0]._expr._get_dependencies())):
+                    if  self.line.ref.elements[nn_kick].ksl[0]._expr is not None:
+                        self.line.ref.elements[nn_kick].ksl[0] += ( # ksl[0] is +kick
                             self.line.vars[f'orbit_corr_{nn_kick}_y'])
                     else:
                         # Workarond for https://github.com/xsuite/xsuite/issues/501
-                        val = self.line.element_refs[nn_kick].ksl[0]._value
+                        val = self.line.ref.elements[nn_kick].ksl[0]._value
                         if hasattr(val, 'get'):
                             val = val.get()
-                        self.line.element_refs[nn_kick].ksl[0] = val + (
+                        self.line.ref.elements[nn_kick].ksl[0] = val + (
                             self.line.vars[f'orbit_corr_{nn_kick}_y'])
 
             self.correction_knobs.append(corr_knob_name)
